==> udm-plugin-api-3.5.1-sources.jar: com/xebialabs/deployit/plugin/api/deployment/execution/Plans.java <==
package com.xebialabs.deployit.plugin.api.deployment.execution;

import com.google.common.collect.Lists;
import com.xebialabs.deployit.plugin.api.deployment.specification.Delta;

import java.util.Arrays;
import java.util.List;

import static com.google.common.collect.Lists.newArrayList;

public class Plans {
    public static InterleavedPlan interleaved(Delta... operations) {
        return new InterleavedPlan(operations);
    }

    public static ParallelPlan parallel(Plan... plans) {
        return new ParallelPlan(plans);
    }

    public static ParallelPlan parallel(List<Plan> plans) {
        return new ParallelPlan(plans);
    }

    public static SerialPlan serial(Plan... plans) {
        return new SerialPlan(plans);
    }

    public static SerialPlan serial(List<Plan> plans) {
        return new SerialPlan(plans);
    }

    public static InterleavedPlan interleaved(List<DeploymentStep> steps) {
        return new InterleavedPlan(Lists.<Delta>newArrayList(), steps);
    }

    public static InterleavedPlanBuilder newInterleavedPlan(InterleavedPlan original) {
        return new InterleavedPlanBuilder(original);
    }

    public static class InterleavedPlanBuilder {
        private List<Delta> operations;
        private List<DeploymentStep> steps;

        private InterleavedPlanBuilder(InterleavedPlan original) {
            operations = original.getDeltas();
            steps = newArrayList(original.getSteps());
        }

        public InterleavedPlanBuilder withStep(DeploymentStep step) {
            steps.add(step);
            return this;
        }

        public InterleavedPlanBuilder withSteps(List<DeploymentStep> steps) {
            this.steps.addAll(steps);
            return this;
        }

        public InterleavedPlanBuilder withSteps(DeploymentStep... steps) {
            this.steps.addAll(Arrays.asList(steps));
            return this;
        }

        public InterleavedPlanBuilder replaceAllSteps(List<DeploymentStep> steps) {
            this.steps = steps;
            return this;
        }

        public InterleavedPlanBuilder clearSteps() {
            this.steps = newArrayList();
            return this;
        }

        public InterleavedPlanBuilder replaceStep(DeploymentStep old, DeploymentStep newStep) {
            if (steps.contains(old)) {
                int i = steps.indexOf(old);
                steps.remove(i);
                steps.add(i, newStep);
                return this;
            }
            throw new IllegalArgumentException("Could not find " + old + " in step list");
        }

        public InterleavedPlan build() {
            return new InterleavedPlan(operations, steps);
        }
    }
}

==> udm-plugin-api-3.5.1.1-sources.jar: com/xebialabs/deployit/plugin/api/deployment/execution/Plans.java <==
package com.xebialabs.deployit.plugin.api.deployment.execution;

import com.google.common.collect.ArrayListMultimap;
import com.google.common.collect.ListMultimap;
import com.google.common.collect.Lists;
import com.xebialabs.deployit.plugin.api.deployment.specification.Delta;

import java.util.Arrays;
import java.util.List;

import static com.google.common.collect.Lists.newArrayList;

public class Plans {
    public static InterleavedPlan interleaved(Delta... operations) {
        return new InterleavedPlan(operations);
    }

    public static ParallelPlan parallel(Plan... plans) {
        return new ParallelPlan(plans);
    }

    public static ParallelPlan parallel(List<Plan> plans) {
        return new ParallelPlan(plans);
    }

    public static SerialPlan serial(Plan... plans) {
        return new SerialPlan(plans);
    }

    public static SerialPlan serial(List<Plan> plans) {
        return new SerialPlan(plans);
    }

    public static InterleavedPlan interleaved(ListMultimap<Integer, DeploymentStep> steps) {
        return new InterleavedPlan(Lists.<Delta>newArrayList(), steps);
    }

    public static InterleavedPlanBuilder newInterleavedPlan(InterleavedPlan original) {
        return new InterleavedPlanBuilder(original);
    }

    public static class InterleavedPlanBuilder {
        private List<Delta> operations;
        private ListMultimap<Integer, DeploymentStep> steps;

        private InterleavedPlanBuilder(InterleavedPlan original) {
            operations = original.getDeltas();
            steps = ArrayListMultimap.create(original.getStepsMap());
        }

        public InterleavedPlanBuilder withStep(DeploymentStep step) {
            steps.put(step.getOrder(), step);
            return this;
        }

        public InterleavedPlanBuilder withSteps(List<DeploymentStep> steps) {
	        for (DeploymentStep step : steps) {
		        this.steps.put(step.getOrder(), step);
	        }
            return this;
        }

        public InterleavedPlanBuilder withSteps(DeploymentStep... steps) {
	        for (DeploymentStep step : steps) {
		        this.steps.put(step.getOrder(), step);
	        }
            return this;
        }

        public InterleavedPlanBuilder replaceAllSteps(ListMultimap<Integer, DeploymentStep> steps) {
            this.steps = steps;
            return this;
        }

        public InterleavedPlan build() {
            return new InterleavedPlan(operations, steps);
        }
    }
}
